@@ -710,6 +710,17 @@ class Agent(Insight, Channel, Catalog, Dataset):
         r = s.post(url=authentication_url, headers=self._headers, json=data)
         r.raise_for_status()
 
+    def get_collaborators_for_channel(self, channel_slug):
+
+        channel_id = self.get_channel(channel_slug)["id"]
+        url = "{}/smartfeed/channels/{}/users".format(self._base_url, channel_id)
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+        r = s.get(url=url, headers=self._headers)
+        r.raise_for_status()
+        return r.json()[0]
 
     def get_channel(self, channel_slug):
 
